fnss.netconfig.nodeconfig.remove_stack — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.remove_stack

`remove_stack`(topology, node)

  Remove stack from a node

  Parameters : | topology : Topology The topology node : any hashable type The ID of the node

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »